@@ -67,16 +67,15 @@ if __name__ == "__main__":
 
     placeHolder = 'VERSION'
     # projectDir = '/Users/didi/DidiProjects/PassengerSug-dev'
-    projectDir = '/Users/didi/DidiProjects/PassengerMapFlow'
-    lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*(.*)'
-    version = Replace.get_string(projectDir, fileType, lookup_str)
-    print(version + '+++++++')
+    # projectDir = '/Users/didi/DidiProjects/PassengerMapFlow'
+    # lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*)\'?[1-9]+.*\'?$'
+    # version = Replace.get_string(projectDir, fileType, lookup_str)
+    # print(version + '+++++++')
 
-    # newVersion = Utils.generate_verison(version, 'rtl')
+    # newVersion = Utils.generate_verison(version, 'test')
     # print('new verison:' + newVersion)
 
     
-    # projectDir = '/Users/didi/DidiProjects/GlobalPassenger'
     # placeHolder = 'map_global_sdk_version'
     
     # lookup_table=[[r'(^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*)\'?[1-9]+.*\'?$', "\\1\'%s\'" %newVersion]]
